from django.http import HttpResponse, Http404
from django.shortcuts import render_to_response, redirect
import GeoIP
from collect.models import *
import log
import logging

logger = logging.getLogger('mainlogger')

def confirm(request):
    return render_to_response('confirm.html')

def hit(request, clientIP=None):
    if not clientIP:
        clientIP = request.META['REMOTE_ADDR']
    gir = getCityCountry(clientIP)
    logger.debug( 'Request from %s, gir: %s' % (clientIP,gir) )
    # Make sure gir exists and has the fields we need
    if gir and gir['city'] and gir['country_name']:
        # Massage International Strings
        gir['city'] = gir['city'].decode('latin1', 'replace')
        gir['country_name'] = gir['country_name'].decode('latin1', 'replace')

        countries = Country.objects.filter(name=gir['country_name'])
        cities  = City.objects.filter(name=gir['city'])
        if not countries:
            # New country, create it
            client_country = Country.objects.create( name=gir['country_name'],latitude=gir['latitude'],longitude=gir['longitude'])
            logger.debug( 'Created new country %s' % (client_country) )
        else:
            # Existing one, get it
            client_country = countries[0]
            logger.debug( 'Existing country %s' % (client_country) )

        if not cities:
            # New city, create it
            client_city = City.objects.create( name=gir['city'],latitude=gir['latitude'],longitude=gir['longitude'],country=client_country)
            # When adding a new city, we adjust logo location for its country (averaging with old location)
            client_country.longitude = (client_country.longitude + client_city.longitude) / 2
            client_country.latitude = (client_country.latitude + client_city.latitude) / 2
            client_country.save()
            logger.debug( 'Created new city %s' % (client_city) )
        # Useless: no need to get city
        #else:
        #    # Existing one, get it
        #    client_city = cities[0]
        #    logger.debug( 'Existing city %s' % (client_city) )
    else:
        # getCityCountry returned null, not really the user's problem
        # We still redirect user to map
        logger.error( 'gir was none, client IP is %s' % (clientIP) )
        pass

    # TODO: redirect by looking up the mapview "view" instead of using a URL
    return redirect('/map/')

def getCityCountry(IP):
    gi = GeoIP.open("/usr/share/GeoIP/GeoLiteCity.dat",GeoIP.GEOIP_STANDARD)
    gir = gi.record_by_addr(IP)
    # We return gir, even if it's None
    return gir
